import React, { Component } from "react";
import axios from "axios";

import { Input } from "../input";

const FORM_TEMPLATE = {
	email: {
		type: "email",
		name: "email",
		label: "Email",
		placeholder: "Your email",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			}
		},
		touch: false,
		valid: false
	},
	password: {
		type: "password",
		name: "password",
		label: "Password",
		placeholder: "Your password",
		value: "",
		validate: {
			require: {
				cb: v => v.trim() === ""
			},
			minL: {
				cb: v => v.trim().length < 6
			}
		},
		touch: false,
		valid: false
	}
};

export default class AuthForm extends Component {
	state = {
		form: FORM_TEMPLATE,
		formValid: false
	};

	validator = (rules, value) => {
		const valid = Object.keys(rules).reduce((prev, elem) => {
			if (prev) return true;
			const check = rules[elem].cb(value);
			if (!prev && check) return check;

			return false;
		}, false);

		return valid;
	};

	onChangeHandler = e => {
		const { value, name } = e.target;

		this.setState(prevState => ({
			...prevState,
			form: {
				...prevState.form,
				[name]: {
					...prevState.form[name],
					value,
					touch: true,
					valid: this.validator(prevState.form[name].validate, value)
				}
			}
		}));
	};

	clearEvent = () => this.setState({ form: FORM_TEMPLATE, formValid: false });

	sendRequest = () => {
		const values = Object.keys(this.state.form).reduce((prev, elem) => {
			return { ...prev, [elem]: this.state.form[elem].value };
		}, {});

		axios({
			url: "https://api-clinics.herokuapp.com/api/v1/auth/login",
			method: "POST",
			withCredentials: true,
			data: values
		})
			.then(res => console.log("res", res))
			.catch(err => console.log("err", err));
		console.log("values", values);
	};

	render() {
		const { form } = this.state;
		console.log("this.", this.state);
		return (
			<div>
				<form>
					{Object.keys(form).map(el => (
						<Input
							key={el}
							placeholder={form[el].placeholder}
							name={form[el].name}
							value={form[el].value}
							onChange={this.onChangeHandler}
							label={form[el].label}
							type={form[el].type}
							valid={form[el].valid}
							touch={form[el].touch}
						/>
					))}
					{/* <Input
						placeholder="Your email"
						name="email"
						value={email}
						onChange={this.onChangeHandler}
						label="Email"
					/>
					<Input
						name="password"
						value={password}
						onChange={this.onChangeHandler}
						label="Password"
						type="password"
					/> */}

					<button onClick={this.sendRequest} type="button">
						Log In
					</button>
					<button onClick={this.clearEvent} type="button">
						Clear
					</button>
				</form>
			</div>
		);
	}
}
